IdentWithRange

Struct IdentWithRange 

pub struct IdentWithRange<'src> {
    pub identifier: Ident<'src>,
    pub range: Option<Range<'src>>,
    /* private fields */
}
An expression where an identifier can be accompanied by a range (e.g. #a in <range>).

The range is optional thought, so expressions like #a are also represented by this struct.

Fields

identifier: Ident<'src>range: Option<Range<'src>>